@@ -14,7 +14,7 @@ import (
 
 	"github.com/golang/glog"
 
-	"github.com/openshift/api/apps/v1"
+	v1 "github.com/openshift/api/apps/v1"
 	appsclient "github.com/openshift/client-go/apps/clientset/versioned"
 )
 
